Config

Struct Config 

pub struct Config { /* private fields */ }
Relay’s Configuration.

Implementations

Source

impl Config

pub fn from_path<P: AsRef<Path>>(path: P) -> Result<Config>

Loads a config from a given config folder.

pub fn from_json_value(value: Value) -> Result<Config>

Creates a config from a JSON value.

This is mostly useful for tests.

pub fn apply_override( &mut self, overrides: OverridableConfig, ) -> Result<&mut Self>

Override configuration with values coming from other sources (e.g. env variables or command line parameters).

If applying the overrides fails, the config may be left in an inconsistent state.

pub fn config_exists<P: AsRef<Path>>(path: P) -> bool

Checks if the config is already initialized.

pub fn path(&self) -> &Path

Returns the filename of the config file.

pub fn to_yaml_string(&self) -> Result<String>

Dumps out a YAML string of the values.

pub fn replace_credentials( &mut self, credentials: Option<Credentials>, ) -> Result<bool>

Set new credentials.

This also writes the credentials back to the file, if this config was loaded from the file-system.

pub fn reload(&self) -> Result<bool>

Reloads the configuration from disk.

Returns true if the configuration changed.

In order for a config to be reloadable it must’ve been loaded from a path. The original config will be re-read and reloadable parts of the config will be replaced with their updated values.

If the reload fails for any reason, the current config is untouched.

pub fn current(&self) -> ConfigSnapshot

Acquires a current snapshot of the config.

A snapshot is the way to actually consume values from the config. A snapshot should ideally be acquired once per unit of work.