pub struct Metrics {
pub statsd: Option<String>,
pub statsd_buffer_size: Option<usize>,
pub prefix: String,
pub default_tags: BTreeMap<String, String>,
pub hostname_tag: Option<String>,
pub periodic_secs: u64,
}Expand description
Control the metrics.
Fields
statsd: Option<String>Hostname and port of the statsd server.
Defaults to None.
statsd_buffer_size: Option<usize>Buffer size used for metrics sent to the statsd socket.
Defaults to None.
prefix: StringCommon prefix that should be added to all metrics.
Defaults to "sentry.relay".
Default tags to apply to all metrics.
hostname_tag: Option<String>Tag name to report the hostname to for each metric. Defaults to not sending such a tag.
periodic_secs: u64Interval for periodic metrics emitted from Relay.
Setting it to 0 seconds disables the periodic metrics.
Defaults to 5 seconds.