pub struct ObjectstoreAuthConfig {
pub key_id: String,
pub signing_key: String,
}Expand description
Configuration options for objectstore’s auth scheme.
Fields
key_id: StringIdentifier for the private key used to sign objectstore’s tokens. Must correspond to a public key configured in objectstore.
signing_key: StringEdDSA private key used to sign Objectstore’s tokens, in PEM format.