pub struct UpstreamDescriptor { /* private fields */ }Expand description
The upstream target is a type that holds all the information to uniquely identify an upstream target.
Implementations
Sourceimpl UpstreamDescriptor
impl UpstreamDescriptor
Sourcepub fn new<T>(host: T, port: u16, scheme: Scheme) -> Self
pub fn new<T>(host: T, port: u16, scheme: Scheme) -> Self
Manually constructs an upstream descriptor.
Sourcepub fn from_dsn(dsn: &Dsn) -> Self
pub fn from_dsn(dsn: &Dsn) -> Self
Given a DSN this returns an upstream descriptor that describes it.
Sourcepub fn socket_addr(self) -> Result<SocketAddr, UpstreamError>
pub fn socket_addr(self) -> Result<SocketAddr, UpstreamError>
Returns the socket address of the upstream.
This might perform a DSN lookup and could fail. Callers are encouraged this call this regularly as DNS might be used for load balancing purposes and results might expire.