pub struct Limits {Show 31 fields
pub max_concurrent_requests: usize,
pub max_concurrent_queries: usize,
pub max_event_size: ByteSize,
pub max_attachment_size: ByteSize,
pub max_upload_size: ByteSize,
pub max_attachments_size: ByteSize,
pub max_client_reports_size: ByteSize,
pub max_check_in_size: ByteSize,
pub max_envelope_size: ByteSize,
pub max_session_count: usize,
pub max_api_payload_size: ByteSize,
pub max_api_file_upload_size: ByteSize,
pub max_api_chunk_upload_size: ByteSize,
pub max_profile_size: ByteSize,
pub max_trace_metric_size: ByteSize,
pub max_log_size: ByteSize,
pub max_span_size: ByteSize,
pub max_container_size: ByteSize,
pub max_statsd_size: ByteSize,
pub max_metric_buckets_size: ByteSize,
pub max_replay_compressed_size: ByteSize,
pub max_replay_message_size: ByteSize,
pub max_removed_attribute_key_size: ByteSize,
pub max_thread_count: usize,
pub max_pool_concurrency: usize,
pub query_timeout: u64,
pub shutdown_timeout: u64,
pub keepalive_timeout: u64,
pub idle_timeout: Option<u64>,
pub max_connections: Option<usize>,
pub tcp_listen_backlog: u32,
/* private fields */
}Expand description
Controls various limits
Fields
max_concurrent_requests: usizeHow many requests can be sent concurrently from Relay to the upstream before Relay starts buffering.
max_concurrent_queries: usizeHow many queries can be sent concurrently from Relay to the upstream before Relay starts buffering.
The concurrency of queries is additionally constrained by max_concurrent_requests.
max_event_size: ByteSizeThe maximum payload size for events.
max_attachment_size: ByteSizeThe maximum size for each attachment.
max_upload_size: ByteSizeThe maximum size for a TUS upload request body.
max_attachments_size: ByteSizeThe maximum combined size for all attachments in an envelope or request.
max_client_reports_size: ByteSizeThe maximum combined size for all client reports in an envelope or request.
max_check_in_size: ByteSizeThe maximum payload size for a monitor check-in.
max_envelope_size: ByteSizeThe maximum payload size for an entire envelopes. Individual limits still apply.
max_session_count: usizeThe maximum number of session items per envelope.
max_api_payload_size: ByteSizeThe maximum payload size for general API requests.
max_api_file_upload_size: ByteSizeThe maximum payload size for file uploads and chunks.
max_api_chunk_upload_size: ByteSizeThe maximum payload size for chunks
max_profile_size: ByteSizeThe maximum payload size for a profile
max_trace_metric_size: ByteSizeThe maximum payload size for a trace metric.
max_log_size: ByteSizeThe maximum payload size for a log.
max_span_size: ByteSizeThe maximum payload size for a span.
max_container_size: ByteSizeThe maximum payload size for an item container.
max_statsd_size: ByteSizeThe maximum payload size for a statsd metric.
max_metric_buckets_size: ByteSizeThe maximum payload size for metric buckets.
max_replay_compressed_size: ByteSizeThe maximum payload size for a compressed replay.
max_replay_message_size: ByteSizeThe maximum size for a replay recording Kafka message.
max_removed_attribute_key_size: ByteSizeThe byte size limit up to which Relay will retain keys of invalid/removed attributes.
This is only relevant for EAP items (spans, logs, …). In principle, we want to record all deletions of attributes, but we have to institute some limit to protect our infrastructure against excessive metadata sizes.
Defaults to 10KiB.
max_thread_count: usizeThe maximum number of threads to spawn for CPU and web work, each.
The total number of threads spawned will roughly be 2 * max_thread_count. Defaults to
the number of logical CPU cores on the host.
max_pool_concurrency: usizeControls the maximum concurrency of each worker thread.
Increasing the concurrency, can lead to a better utilization of worker threads by
increasing the amount of I/O done concurrently.
Currently has no effect on defaults to 1.
query_timeout: u64The maximum number of seconds a query is allowed to take across retries. Individual requests have lower timeouts. Defaults to 30 seconds.
shutdown_timeout: u64The maximum number of seconds to wait for pending envelopes after receiving a shutdown signal.
keepalive_timeout: u64Server keep-alive timeout in seconds.
By default, keep-alive is set to 5 seconds.
idle_timeout: Option<u64>Server idle timeout in seconds.
The idle timeout limits the amount of time a connection is kept open without activity. Setting this too short may abort connections before Relay is able to send a response.
By default there is no idle timeout.
max_connections: Option<usize>Sets the maximum number of concurrent connections.
Upon reaching the limit, the server will stop accepting connections.
By default there is no limit.
tcp_listen_backlog: u32The TCP listen backlog.
Configures the TCP listen backlog for the listening socket of Relay.
See man listen(2)
for a more detailed description of the listen backlog.
Defaults to 1024, a value google has been using for a long time.