pub struct ObjectstoreServiceConfig {
pub objectstore_url: Option<String>,
pub max_concurrent_requests: usize,
pub max_backlog: usize,
pub timeout: u64,
pub stream_timeout: u64,
pub retry_delay: f64,
pub max_attempts: NonZeroU16,
pub auth: Option<ObjectstoreAuthConfig>,
}Expand description
Configuration values for the objectstore service.
Fields
objectstore_url: Option<String>The base URL for the objectstore service.
This defaults to None, which means that the service will be disabled,
unless a proper configuration is provided.
max_concurrent_requests: usizeMaximum concurrency of uploads.
max_backlog: usizeMaximum size of the service input queue when max_concurrent_requests is saturated.
The service will loadshed if this threshold is reached.
timeout: u64Maximum duration of an attachment upload in seconds. Uploads that take longer are discarded.
NOTE: This timeout applies to attachments that are already in-memory. Streaming uploads
might take longer and are restricted independently by Self::stream_timeout.
stream_timeout: u64Maximum duration of an upload stream.
Streams get a larger default timeout because their duration depends on the client as well as the server.
retry_delay: f64Time between upload attempts.
max_attempts: NonZeroU16Maximum number of attempts made to upload.
auth: Option<ObjectstoreAuthConfig>Configuration values for objectstore’s auth scheme.