pub struct Outcomes {
pub emit_outcomes: EmitOutcomes,
pub batch_size: usize,
pub batch_interval: u64,
pub source: Option<String>,
pub aggregator: OutcomeAggregatorConfig,
}Expand description
Outcome generation specific configuration values.
Fields
emit_outcomes: EmitOutcomesControls whether outcomes will be emitted when processing is disabled. Processing relays always emit outcomes (for backwards compatibility). Can take the following values: false, “as_client_reports”, true
batch_size: usizeThe maximum number of outcomes that are batched before being sent via http to the upstream (only applies to non processing relays).
batch_interval: u64The maximum time interval (in milliseconds) that an outcome may be batched via http to the upstream (only applies to non processing relays).
source: Option<String>Defines the source string registered in the outcomes originating from this Relay (typically something like the region or the layer).
aggregator: OutcomeAggregatorConfigConfigures the outcome aggregator.